@@ -427,6 +427,11 @@ class MusePointings(SofPipe, PipeRecipes):
 
         self.pipe_params.init_default_param(dict_combined_folders)
         self._dict_combined_folders = dict_combined_folders
+        # List of datasets to process
+        self.list_datasets = self._check_list_datasets(list_datasets)
+        if check:
+            # List of pointings to process
+            self.list_pointings = self._check_list_pointings(list_pointings)
 
         # Setting all the useful paths
         self.set_fullpath_names()
@@ -435,11 +440,6 @@ class MusePointings(SofPipe, PipeRecipes):
         # and Recording the folder where we start
         self.paths.orig = os.getcwd()
 
-        # List of datasets to process
-        self.list_datasets = self._check_list_datasets(list_datasets)
-        if check:
-            # List of pointings to process
-            self.list_pointings = self._check_list_pointings(list_pointings)
         # END Set up params =======================================
 
         # =========================================================== 
@@ -784,11 +784,12 @@ class MusePointings(SofPipe, PipeRecipes):
         # Creating the filenames for Master files
         self.dict_name_datasets = {}
         for dataset in self.list_datasets:
-            name_dataset = get_dataset_name(dataset, str_dataset, ndigits)
+            name_dataset = get_dataset_name(dataset, self.pipe_params.str_dataset,
+                                            self.pipe_params.ndigits)
             self.dict_name_datasets[dataset] = name_dataset
             # Adding the path of the folder
             setattr(self.paths, name_dataset, joinpath(self.paths.root,
-                                                       "{self.targetname}/{name_dataset}/")
+                                                       f"{self.targetname}/{name_dataset}/"))
 
         # Creating the attributes for the folders needed in the TARGET root folder, e.g., for alignments
         for name in self.pipe_params._dict_folders_target:
